@@ -12,3 +12,8 @@ def path_to_object(path):
 
     return obj
 
+def split1000(s, sep=','):
+    """http://www.python.org.br/wiki/FormatarNumeros"""
+    #return s if len(s) <= 3 else split1000(s[:-3], sep) + sep + s[-3:]
+    return len(s) <= 3 and s or split1000(s[:-3], sep) + sep + s[-3:]
+
